==> cdk-lambda-subminute-2.0.148-sources.jar: io/github/hsiehshujeng/cdk/lambda/subminute/IteratorLambda.java <==
package io.github.hsiehshujeng.cdk.lambda.subminute;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.80.0 (build bce6a1d)", date = "2023-05-10T01:14:30.138Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.github.hsiehshujeng.cdk.lambda.subminute.$Module.class, fqn = "cdk-lambda-subminute.IteratorLambda")
public class IteratorLambda extends software.constructs.Construct {

    protected IteratorLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected IteratorLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param name This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public IteratorLambda(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.NotNull io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(name, "name is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A Lambda function that plays the role of the iterator.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction getFunction() {
        return software.amazon.jsii.Kernel.get(this, "function", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.IFunction.class));
    }

    /**
     * A fluent builder for {@link io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param name This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String name) {
            return new Builder(scope, name);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String name;
        private final io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambdaProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String name) {
            this.scope = scope;
            this.name = name;
            this.props = new io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambdaProps.Builder();
        }

        /**
         * The Lambda function that is going to be executed per time unit less than one minute.
         * <p>
         * @return {@code this}
         * @param targetFunction The Lambda function that is going to be executed per time unit less than one minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetFunction(final software.amazon.awscdk.services.lambda.IFunction targetFunction) {
            this.props.targetFunction(targetFunction);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda build() {
            return new io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda(
                this.scope,
                this.name,
                this.props.build()
            );
        }
    }
}

==> cdk-lambda-subminute-2.0.417-sources.jar: io/github/hsiehshujeng/cdk/lambda/subminute/IteratorLambda.java <==
package io.github.hsiehshujeng.cdk.lambda.subminute;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-03-30T01:02:55.405Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.github.hsiehshujeng.cdk.lambda.subminute.$Module.class, fqn = "cdk-lambda-subminute.IteratorLambda")
public class IteratorLambda extends software.constructs.Construct {

    protected IteratorLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected IteratorLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param name This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public IteratorLambda(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.NotNull io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(name, "name is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * A Lambda function that plays the role of the iterator.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction getFunction() {
        return software.amazon.jsii.Kernel.get(this, "function", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.IFunction.class));
    }

    /**
     * A fluent builder for {@link io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param name This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String name) {
            return new Builder(scope, name);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String name;
        private final io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambdaProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String name) {
            this.scope = scope;
            this.name = name;
            this.props = new io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambdaProps.Builder();
        }

        /**
         * The Lambda function that is going to be executed per time unit less than one minute.
         * <p>
         * @return {@code this}
         * @param targetFunction The Lambda function that is going to be executed per time unit less than one minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetFunction(final software.amazon.awscdk.services.lambda.IFunction targetFunction) {
            this.props.targetFunction(targetFunction);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda build() {
            return new io.github.hsiehshujeng.cdk.lambda.subminute.IteratorLambda(
                this.scope,
                this.name,
                this.props.build()
            );
        }
    }
}
